@@ -1,14 +1,15 @@
 #' @rdname estimate_grouplevel
 #' @param x The output of `estimate_grouplevel()`.
-#' @param indices A list containing the indices to extract.
+#' @param indices A list containing the indices to extract (e.g., "Coefficient").
+#' @param group A list containing the random factors to select.
 #' @export
-reshape_grouplevel <- function(x, indices = "all", ...) {
+reshape_grouplevel <- function(x, indices = "all", group = "all", ...) {
   UseMethod("reshape_grouplevel")
 }
 
 
 #' @export
-reshape_grouplevel.estimate_grouplevel <- function(x, indices = "all", ...) {
+reshape_grouplevel.estimate_grouplevel <- function(x, indices = "all", group = "all", ...) {
   # Find indices
   if (any(indices == "all")) {
     indices <- names(x)[!names(x) %in% c("Group", "Level", "Parameter", "CI")]
@@ -22,23 +23,23 @@ reshape_grouplevel.estimate_grouplevel <- function(x, indices = "all", ...) {
   indices <- names(x)[names(x) %in% unique(indices)]
 
 
-  # Get original data frame of random
+  # Get original dataframe of random
   data <- attributes(x)$data
 
   # Random parameters
-  groups <- unique(x$Group)
+  if (all(group == "all")) group <- unique(x$Group)
 
   # Loop through all groups
-  for (group in groups) {
+  for (g in group) {
     # Subset coefficients
-    data_group <- x[x$Group == group, ]
+    data_group <- x[x$Group == g, ]
 
     # If no data, skip
     if (nrow(data_group) == 0) next
 
     # Clean subset of random factors
-    data_group[[group]] <- data_group$Level
-    newvars <- paste0(group, "_", indices)
+    data_group[[g]] <- data_group$Level
+    newvars <- paste0(g, "_", indices)
     names(data_group)[names(data_group) %in% indices] <- newvars
 
     # Reshape
@@ -48,25 +49,25 @@ reshape_grouplevel.estimate_grouplevel <- function(x, indices = "all", ...) {
     )
 
     data_wide <- datawizard::data_to_wide(
-      data_group[c(group, newvars, "Parameter")],
-      id_cols = group,
+      data_group[c(g, newvars, "Parameter")],
+      id_cols = g,
       values_from = newvars,
       names_from = "Parameter",
       names_sep = "_"
     )
 
     # If nested, separate groups
-    if (grepl(":", group)) {
-      groups <- as.data.frame(t(sapply(strsplit(data_wide[[group]], ":"), function(x) as.data.frame(t(x)))))
-      names(groups) <- unlist(strsplit(group, ":"))
+    if (grepl(":", g)) {
+      groups <- as.data.frame(t(sapply(strsplit(data_wide[[g]], ":"), function(x) as.data.frame(t(x)))))
+      names(groups) <- unlist(strsplit(g, ":"))
       data_wide <- cbind(groups, data_wide)
-      data_wide[group] <- NULL
-      group <- names(groups)
+      data_wide[g] <- NULL
+      g <- names(groups)
     }
 
     # Merge while preserving order of original random
     data[["__sort_id"]] <- seq_len(nrow(data))
-    data <- merge(data, data_wide, by = group, sort = FALSE)
+    data <- merge(data, data_wide, by = g, sort = FALSE)
     data <- data[order(data[["__sort_id"]]), ]
     data[["__sort_id"]] <- NULL
   }
