@@ -1,4 +1,4 @@
-if (require("testthat") && require("modelbased") && require("emmeans")) {
+if (require("emmeans")) {
   test_that("attributes_means", {
     model <- lm(Sepal.Length ~ Species * Sepal.Width, data = iris)
 
